@@ -1,62 +1,60 @@
 #![no_std]
 #![allow(non_camel_case_types, non_upper_case_globals, non_snake_case)]
 
-extern crate libc;
-
-pub use boolobject::*;
-pub use bufferobject::*;
-pub use bytearrayobject::*;
-pub use bytesobject::*;
-pub use cellobject::*;
-pub use ceval::*;
-pub use classobject::*;
-pub use cobject::*;
-pub use code::*;
-pub use compile::*;
-pub use complexobject::*;
-pub use descrobject::*;
-pub use dictobject::*;
-pub use enumobject::*;
-pub use eval::*;
-pub use fileobject::*;
-pub use floatobject::*;
-pub use frameobject::PyFrameObject;
-pub use funcobject::*;
-pub use genobject::*;
-pub use import::*;
-pub use intobject::*;
-pub use iterobject::*;
-pub use listobject::*;
-pub use longobject::*;
-pub use marshal::*;
-pub use memoryobject::*;
-pub use methodobject::*;
-pub use modsupport::*;
-pub use moduleobject::*;
-pub use object::*;
-pub use objectabstract::*;
-pub use objimpl::*;
-pub use pyarena::*;
-pub use pycapsule::*;
-pub use pydebug::*;
-pub use pyerrors::*;
-pub use pymem::*;
-pub use pyport::*;
-pub use pystate::PyGILState_STATE::*;
-pub use pystate::*;
-pub use pythonrun::*;
-pub use rangeobject::*;
-pub use setobject::*;
-pub use sliceobject::*;
-pub use stringobject::*;
-pub use structmember::PyMemberDef;
-pub use sysmodule::*;
-pub use traceback::*;
-pub use tupleobject::*;
+pub use crate::boolobject::*;
+pub use crate::bufferobject::*;
+pub use crate::bytearrayobject::*;
+pub use crate::bytesobject::*;
+pub use crate::cellobject::*;
+pub use crate::ceval::*;
+pub use crate::classobject::*;
+pub use crate::cobject::*;
+pub use crate::code::*;
+pub use crate::compile::*;
+pub use crate::complexobject::*;
+pub use crate::descrobject::*;
+pub use crate::dictobject::*;
+pub use crate::enumobject::*;
+pub use crate::eval::*;
+pub use crate::fileobject::*;
+pub use crate::floatobject::*;
+pub use crate::frameobject::PyFrameObject;
+pub use crate::funcobject::*;
+pub use crate::genobject::*;
+pub use crate::import::*;
+pub use crate::intobject::*;
+pub use crate::iterobject::*;
+pub use crate::listobject::*;
+pub use crate::longobject::*;
+pub use crate::marshal::*;
+pub use crate::memoryobject::*;
+pub use crate::methodobject::*;
+pub use crate::modsupport::*;
+pub use crate::moduleobject::*;
+pub use crate::object::*;
+pub use crate::objectabstract::*;
+pub use crate::objimpl::*;
+pub use crate::pyarena::*;
+pub use crate::pycapsule::*;
+pub use crate::pydebug::*;
+pub use crate::pyerrors::*;
+pub use crate::pymem::*;
+pub use crate::pyport::*;
+pub use crate::pystate::PyGILState_STATE::*;
+pub use crate::pystate::*;
+pub use crate::pythonrun::*;
+pub use crate::rangeobject::*;
+pub use crate::setobject::*;
+pub use crate::sliceobject::*;
+pub use crate::stringobject::*;
+pub use crate::structmember::PyMemberDef;
+pub use crate::sysmodule::*;
+pub use crate::traceback::*;
+pub use crate::tupleobject::*;
 #[cfg(py_sys_config = "Py_USING_UNICODE")]
-pub use unicodeobject::*;
-pub use warnings::*;
-pub use weakrefobject::*;
+pub use crate::unicodeobject::*;
+pub use crate::warnings::*;
+pub use crate::weakrefobject::*;
 
 mod pyport;
 
